/***************************************************************************
 *   Copyright (C) 2001 by Rick L. Vinyard, Jr.                            *
 *   rvinyard@cs.nmsu.edu                                                  *
 *                                                                         *
 *   This file is part of the conexus library.                             *
 *                                                                         *
 *   The conexus library is free software; you can redistribute it and/or  *
 *   modify it under the terms of the GNU General Public License           *
 *   version 3 as published by the Free Software Foundation.               *
 *                                                                         *
 *   The conexus library is distributed in the hope that it will be        *
 *   useful, but WITHOUT ANY WARRANTY; without even the implied warranty   *
 *   of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU   *
 *   General Public License for more details.                              *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this software. If not see <http://www.gnu.org/licenses/>.  *
 ***************************************************************************/
#ifndef CONEXUSGTKMMHOSTPORTENTRY_H
#define CONEXUSGTKMMHOSTPORTENTRY_H

#include <gtkmm.h>

#include <conexus-gtkmm/hostentry.h>
#include <conexus-gtkmm/portentry.h>

#ifdef CONEXUS_HAVE_DBUS
#include <conexus-dbus.h>
#endif

namespace Conexus
{
  namespace Gtk
  {

    /**
    @author Rick L Vinyard Jr
    */
    class HostPortEntry : public ::Gtk::Table
    {
      public:
        typedef enum Layout { VERTICAL, HORIZONTAL } Layout;
        
        HostPortEntry ( Layout layout = VERTICAL );
        HostPortEntry( IPAddressInterface* addr, unsigned lookup = LOOKUP_IPV4|LOOKUP_IPV6, Layout layout = VERTICAL );
        HostPortEntry( IPAddressInterface::pointer addr, unsigned lookup = LOOKUP_IPV4|LOOKUP_IPV6, Layout layout = VERTICAL );
        HostPortEntry( IPv4::Address& addr, unsigned lookup = LOOKUP_IPV4, Layout layout = VERTICAL );
        HostPortEntry( IPv6::Address& addr, unsigned lookup = LOOKUP_IPV6, Layout layout = VERTICAL );

        ~HostPortEntry();

        void set_address( IPAddressInterface* addr, unsigned lookup = LOOKUP_IPV4 );
        void set_address( IPAddressInterface::pointer addr, unsigned lookup = LOOKUP_IPV4 );
        void set_address( IPv4::Address& addr, unsigned lookup = LOOKUP_IPV4 );
        void set_address( IPv6::Address& addr, unsigned lookup = LOOKUP_IPV6 );

        void unset_address();

        HostEntry& host_entry();
        PortEntry& port_entry();

        Layout layout();
        void set_layout ( Layout layout );

      protected:
        HostEntry m_host;
        PortEntry m_port;
        ::Gtk::Alignment m_host_alignment, m_port_alignment;
        Layout m_layout;

        void setup_widget();
    };

  }

}

#endif
