/***************************************************************************
 *   Copyright (C) 2001 by Rick L. Vinyard, Jr.                            *
 *   rvinyard@cs.nmsu.edu                                                  *
 *                                                                         *
 *   This file is part of the conexus library.                             *
 *                                                                         *
 *   The conexus library is free software; you can redistribute it and/or  *
 *   modify it under the terms of the GNU General Public License           *
 *   version 3 as published by the Free Software Foundation.               *
 *                                                                         *
 *   The conexus library is distributed in the hope that it will be        *
 *   useful, but WITHOUT ANY WARRANTY; without even the implied warranty   *
 *   of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU   *
 *   General Public License for more details.                              *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this software. If not see <http://www.gnu.org/licenses/>.  *
 ***************************************************************************/
#ifndef CONEXUSGTKMMPORTENTRY_H
#define CONEXUSGTKMMPORTENTRY_H

#include <gtkmm.h>

#include <conexus.h>
#include <conexus-gtkmm/enums.h>

namespace Conexus
{
  namespace Gtk
  {

    /**
     * TODO need to add TCP/UDP service lookup for those that do differ
     * @author Rick L Vinyard Jr
     */
    class PortEntry : public ::Gtk::VBox
    {
      public:
        PortEntry( unsigned lookup = LOOKUP_IPV4|LOOKUP_IPV6 );
        PortEntry( IPAddressInterface* addr, unsigned lookup = LOOKUP_IPV4 );
        PortEntry( IPAddressInterface::pointer addr, unsigned lookup = LOOKUP_IPV4 );
        PortEntry( IPv4::Address& addr, unsigned lookup = LOOKUP_IPV4 );
        PortEntry( IPv6::Address& addr, unsigned lookup = LOOKUP_IPV6 );

        ~PortEntry();

        IPAddressInterface* address();

        void set_address( IPAddressInterface* addr, unsigned lookup = LOOKUP_IPV4 );
        void set_address( IPAddressInterface::pointer addr, unsigned lookup = LOOKUP_IPV4 );
        void set_address( IPv4::Address& addr, unsigned lookup = LOOKUP_IPV4 );
        void set_address( IPv6::Address& addr, unsigned lookup = LOOKUP_IPV6 );

        void unset_address();

        ::Gtk::SpinButton& port_widget();
        ::Gtk::Adjustment& port_widget_adjustment();
        uint32_t port();
        void set_port ( uint32_t p );

        std::string servicename();

        bool is_servicename_label_visible();

        void show_servicename_label ( bool show=true );

        ::Gtk::Button& apply_button();

        bool is_immediate_apply_enabled();

        void enable_immediate_apply( bool enable=true );

        void apply();

      protected:
        IPAddressInterface* m_address;
        
        unsigned m_lookup;
        bool m_immediate_apply;

        sigc::connection m_conn_address_port;

        ::Gtk::SpinButton m_port_widget;
        sigc::connection m_conn_port_widget_changed;
        ::Gtk::Adjustment m_port_widget_adjustment;
        ::Gtk::Label m_servicename_label;
        ::Gtk::Button m_apply_button;

        virtual void on_controlled_port_changed();

        virtual void on_port_widget_changed();

        void on_spinbutton_text_entry ( const Glib::ustring & text, int * position );
        void on_spinbutton_text_delete ( int start, int end );

      private:
        void setup_widget();

    };

  }

}

#endif
